# Check that file contains line that matches regular expression.
# Sets IS_FOUND variable to TRUE if found and to FALSE otherwise.
macro(check_line_exists TARGET_FILE REG_EXP_REF)
    set(IS_FOUND "FALSE")
    
    file(STRINGS ${TARGET_FILE} FOUND_LINE LIMIT_COUNT 1 REGEX "${${REG_EXP_REF}}")
    list(LENGTH FOUND_LINE _VAR_LEN)
    
    if(_VAR_LEN GREATER 0)
        set(IS_FOUND "TRUE")
    endif(_VAR_LEN GREATER 0)
endmacro(check_line_exists TARGET_FILE REG_EXP_REF)

# Search and parse project section line by project name.
# If search was successful stores found type and guid into FOUND_TYPE and FOUND_GUID variables respectively.
# Sets IS_FOUND variable to TRUE if found and to FALSE otherwise.
macro(parse_project_section TARGET_FILE PROJECT_NAME)
    set(REG_EXP "^Project\\(\\\"{(.+)}\\\"\\) = \\\"${PROJECT_NAME}\\\", \\\".+\\..+\\\", \\\"{(.+)}\\\"$")
    
    check_line_exists(${TARGET_FILE} REG_EXP)
    if(NOT IS_FOUND)
        return()
    endif(NOT IS_FOUND)
    
    string(REGEX REPLACE "${REG_EXP}" "\\1;\\2" _GUIDS "${FOUND_LINE}")
    
    list(GET _GUIDS 0 FOUND_TYPE)
    list(GET _GUIDS 1 FOUND_GUID)
endmacro(parse_project_section TARGET_FILE PROJECT_NAME)

# Search project section line by project name and type.
# Returns TRUE if found and FALSE otherwise
function(check_project_type TARGET_FILE PROJECT_NAME PROJECT_TYPE RESULT)
    set(${RESULT} "FALSE" PARENT_SCOPE)
    
    parse_project_section(${TARGET_FILE} ${PROJECT_NAME})
    if(IS_FOUND AND FOUND_TYPE STREQUAL PROJECT_TYPE)
        set(${RESULT} "TRUE" PARENT_SCOPE)
    endif(IS_FOUND AND FOUND_TYPE STREQUAL PROJECT_TYPE)
endfunction(check_project_type TARGET_FILE PROJECT_NAME PROJECT_TYPE RESULT)


# Search project section line by project name and id.
# Returns TRUE if found and FALSE otherwise
function(check_project_guid TARGET_FILE PROJECT_NAME PROJECT_GUID RESULT)
    set(${RESULT} "FALSE" PARENT_SCOPE)
        
    parse_project_section(${TARGET_FILE} ${PROJECT_NAME})
    if(IS_FOUND AND FOUND_GUID STREQUAL PROJECT_GUID)
        set(${RESULT} "TRUE" PARENT_SCOPE)
    endif(IS_FOUND AND FOUND_GUID STREQUAL PROJECT_GUID)
endfunction(check_project_guid TARGET_FILE PROJECT_NAME PROJECT_GUID RESULT)


# Search project's build configuration line by project name and target platform name.
# Returns TRUE if found and FALSE otherwise
function(check_custom_platform TARGET_FILE PROJECT_NAME PLATFORM_NAME RESULT)
    set(${RESULT} "FALSE" PARENT_SCOPE)
    
    # extract project guid
    parse_project_section(${TARGET_FILE} ${PROJECT_NAME})
    if(NOT IS_FOUND)
        return()
    endif(NOT IS_FOUND)
    
    # probably whould be better to use configuration name 
    # extracted from CMAKE_CONFIGURATION_TYPES than just hardcoded "Debug" instead
    set(REG_EXP "^(\t)*\\{${FOUND_GUID}\\}\\.Debug\\|Win32\\.ActiveCfg = Debug\\|${PLATFORM_NAME}$")
    check_line_exists(${TARGET_FILE} REG_EXP)
    
    set(${RESULT} ${IS_FOUND} PARENT_SCOPE)
endfunction(check_custom_platform TARGET_FILE PLATFORM_NAME RESULT)
